==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/mots/lang/mots_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=it
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Gruppo importante:</b> è consigliato selezionare una parola chiave in questo gruppo.',
	'avis_doublon_mot_cle' => 'Una parola esiste già con questo titolo. Sei sicuro di volerne creare una uguale?',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'gli amministratori del sito',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'i redattori',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'i visitatori del sito pubblico quando scrivono un messaggio in un forum.',

	// C
	'creer_et_associer_un_mot' => 'Crea e associa una parola chiave',

	// I
	'icone_creation_groupe_mots' => 'Crea un nuovo gruppo',
	'icone_creation_mots_cles' => 'Crea una nuova parola chiave',
	'icone_modif_groupe_mots' => 'Modifica questo gruppo',
	'icone_modifier_mot' => 'Modifica questa parola chiave',
	'icone_mots_cles' => 'Parole chiave',
	'icone_supprimer_groupe_mots' => 'Elimina il gruppo',
	'icone_voir_groupe_mots' => 'Visualizza questo gruppo di parole chiave',
	'icone_voir_tous_mots_cles' => 'Vedi tutte le parole chiave',
	'info_1_groupe_mots' => '1 gruppo di parole chiave',
	'info_articles_lies_mot' => 'Gli articoli collegati a questa parola chiave',
	'info_aucun_groupe_mots' => 'Nessun gruppo di parole chiave',
	'info_aucun_mot_cle' => 'Nessuna parola chiave',
	'info_changer_nom_groupe' => 'Cambiare il nome di questo gruppo:',
	'info_creation_mots_cles' => 'In questa pagina è possibile creare e configurare le parole chiave del sito',
	'info_dans_groupe' => 'Nel gruppo:',
	'info_delet_mots_cles' => 'Hai chiesto di eliminare la parola chiave <b>@titre_mot@</b> (@type_mot@). Essendo quest\'ultima collegata a <b>@texte_lie@</b>, è necessario confermare la decisione:',
	'info_groupe_important' => 'Gruppo importante',
	'info_modifier_mot' => 'Modifica la parola chiave:',
	'info_mots_cles' => 'Le parole chiave',
	'info_mots_cles_association' => 'Le parole chiave di questo gruppo possono essere associate:',
	'info_nb_groupe_mots' => '@nb@ gruppi di parole chiave',
	'info_oui_suppression_mot_cle' => 'voglio cancellare definitivamente questa parola chiave.',
	'info_question_mots_cles' => 'Vuoi utilizzare le parole chiave nel sito?',
	'info_qui_attribue_mot_cle' => 'Le parole chiave di questo gruppo possono essere attribuite da:',
	'info_remplacer_mot' => 'Sostituisci "@titre@"',
	'info_retirer_mot' => 'Rimuovere questa parola',
	'info_retirer_mots' => 'Rimuovere tutte le parole',
	'info_rubriques_liees_mot' => 'Le rubriche collegate a questa parola chiave',
	'info_selection_un_seul_mot_cle' => 'È consentito selezionare <b>una sola parola chiave</b> alla volta in questo gruppo.',
	'info_supprimer_mot' => 'cancella questa parola',
	'info_titre_mot_cle' => 'Nome o titolo della parola chiave',
	'info_un_mot' => 'Una parola sola alla volta',
	'item_ajout_mots_cles' => 'Consenti l\'uso di parole chiave nei forum',
	'item_non_ajout_mots_cles' => 'Non consentire l\'uso di parole chiave nei forum',
	'item_non_utiliser_config_groupe_mots_cles' => 'Non utilizzare la configurazione avanzata dei gruppi di parole chiave',
	'item_non_utiliser_mots_cles' => 'Non utilizzare le parole chiave',
	'item_utiliser_config_groupe_mots_cles' => 'Utilizza la configurazione avanzata dei gruppi di parole chiave',
	'item_utiliser_mots_cles' => 'Utilizza le parole chiave',

	// L
	'lien_ajouter_mot' => 'Aggiungi una parola chiave',
	'logo_groupe' => 'LOGO DI QUESTO GRUPPO',
	'logo_mot_cle' => 'LOGO DELLA PAROLA CHIAVE',

	// T
	'texte_config_groupe_mots_cles' => 'Vuoi attivare la configurazione avanzata delle parole chiave, indicando per esempio che si può selezionare una parola unica per gruppo o che un gruppo è importante, ecc.?',
	'texte_mots_cles' => 'Le parole chiave permettono di creare dei link tematici tra gli articoli
indipendentemente dal posto che occupano nelle diverse rubriche.
Si può quindi arricchire la navigazione del sito, o utilizzare queste proprietà
per personalizzare la presentazione degli articoli nei tuoi modelli di layout.',
	'texte_mots_cles_dans_forum' => 'Vuoi consentire ai visitatori di selezionare delle parole chiave nei forum pubblici? (Attenzione: questa opzione è relativamente complessa da gestire in modo corretto.)',
	'texte_nouveau_mot' => 'Nuova parola',
	'titre_config_groupe_mots_cles' => 'Configurazione dei gruppi di parole chiave',
	'titre_gauche_mots_edit' => 'PAROLA CHIAVE NUMERO:',
	'titre_groupe_mots' => 'GRUPPI DI PAROLE:',
	'titre_groupe_mots_numero' => 'GRUPPO DI PAROLE NUMERO :',
	'titre_groupes_mots' => 'Gruppi di parole chiave',
	'titre_mots_cles_dans_forum' => 'Parole chiave nel forum del sito pubblico',
	'titre_mots_tous' => 'Le parole chiave',
	'titre_nouveau_groupe' => 'Nuovo gruppo',
	'titre_objets_lies_mot' => 'Correlati a questa parola chiave :',
	'titre_page_mots_tous' => 'Parole chiave'
);

?>

==> spip_3.0.9.orig.tar.xz: spip-3.0.9.orig/plugins-dist/mots/lang/mots_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=it
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Gruppo importante:</b> è consigliato selezionare una parola chiave in questo gruppo.',
	'avis_doublon_mot_cle' => 'Una parola esiste già con questo titolo. Sei sicuro di volerne creare una uguale?', # MODIF

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'gli amministratori del sito',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'i redattori',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'i visitatori del sito pubblico quando scrivono un messaggio in un forum.',

	// C
	'creer_et_associer_un_mot' => 'Crea e associa una parola chiave',

	// I
	'icone_creation_groupe_mots' => 'Crea un nuovo gruppo',
	'icone_creation_mots_cles' => 'Crea una nuova parola chiave',
	'icone_modif_groupe_mots' => 'Modifica questo gruppo',
	'icone_modifier_mot' => 'Modifica questa parola chiave',
	'icone_mots_cles' => 'Parole chiave',
	'icone_supprimer_groupe_mots' => 'Elimina il gruppo',
	'icone_voir_groupe_mots' => 'Visualizza questo gruppo di parole chiave',
	'icone_voir_tous_mots_cles' => 'Vedi tutte le parole chiave',
	'info_1_groupe_mots' => '1 gruppo di parole chiave',
	'info_articles_lies_mot' => 'Gli articoli collegati a questa parola chiave',
	'info_aucun_groupe_mots' => 'Nessun gruppo di parole chiave',
	'info_aucun_mot_cle' => 'Nessuna parola chiave',
	'info_changer_nom_groupe' => 'Cambiare il nome di questo gruppo:',
	'info_creation_mots_cles' => 'In questa pagina è possibile creare e configurare le parole chiave del sito',
	'info_dans_groupe' => 'Nel gruppo:',
	'info_delet_mots_cles' => 'Hai chiesto di eliminare la parola chiave <b>@titre_mot@</b> (@type_mot@). Essendo quest\'ultima collegata a <b>@texte_lie@</b>, è necessario confermare la decisione:',
	'info_groupe_important' => 'Gruppo importante',
	'info_modifier_mot' => 'Modifica la parola chiave:',
	'info_mots_cles' => 'Le parole chiave',
	'info_mots_cles_association' => 'Le parole chiave di questo gruppo possono essere associate:',
	'info_nb_groupe_mots' => '@nb@ gruppi di parole chiave',
	'info_oui_suppression_mot_cle' => 'voglio cancellare definitivamente questa parola chiave.',
	'info_question_mots_cles' => 'Vuoi utilizzare le parole chiave nel sito?',
	'info_qui_attribue_mot_cle' => 'Le parole chiave di questo gruppo possono essere attribuite da:',
	'info_remplacer_mot' => 'Sostituisci "@titre@"',
	'info_retirer_mot' => 'Rimuovere questa parola',
	'info_retirer_mots' => 'Rimuovere tutte le parole',
	'info_rubriques_liees_mot' => 'Le rubriche collegate a questa parola chiave',
	'info_selection_un_seul_mot_cle' => 'È consentito selezionare <b>una sola parola chiave</b> alla volta in questo gruppo.',
	'info_supprimer_mot' => 'cancella questa parola',
	'info_titre_mot_cle' => 'Nome o titolo della parola chiave',
	'info_un_mot' => 'Una parola sola alla volta',
	'item_ajout_mots_cles' => 'Consenti l\'uso di parole chiave nei forum',
	'item_non_ajout_mots_cles' => 'Non consentire l\'uso di parole chiave nei forum',
	'item_non_utiliser_config_groupe_mots_cles' => 'Non utilizzare la configurazione avanzata dei gruppi di parole chiave',
	'item_non_utiliser_mots_cles' => 'Non utilizzare le parole chiave',
	'item_utiliser_config_groupe_mots_cles' => 'Utilizza la configurazione avanzata dei gruppi di parole chiave',
	'item_utiliser_mots_cles' => 'Utilizza le parole chiave',

	// L
	'lien_ajouter_mot' => 'Aggiungi una parola chiave',
	'logo_groupe' => 'LOGO DI QUESTO GRUPPO',
	'logo_mot_cle' => 'LOGO DELLA PAROLA CHIAVE',

	// T
	'texte_config_groupe_mots_cles' => 'Vuoi attivare la configurazione avanzata delle parole chiave, indicando per esempio che si può selezionare una parola unica per gruppo o che un gruppo è importante, ecc.?',
	'texte_mots_cles' => 'Le parole chiave permettono di creare dei link tematici tra gli articoli
indipendentemente dal posto che occupano nelle diverse rubriche.
Si può quindi arricchire la navigazione del sito, o utilizzare queste proprietà
per personalizzare la presentazione degli articoli nei tuoi modelli di layout.',
	'texte_mots_cles_dans_forum' => 'Vuoi consentire ai visitatori di selezionare delle parole chiave nei forum pubblici? (Attenzione: questa opzione è relativamente complessa da gestire in modo corretto.)',
	'texte_nouveau_mot' => 'Nuova parola',
	'titre_config_groupe_mots_cles' => 'Configurazione dei gruppi di parole chiave',
	'titre_gauche_mots_edit' => 'PAROLA CHIAVE NUMERO:',
	'titre_groupe_mots' => 'GRUPPI DI PAROLE:',
	'titre_groupe_mots_numero' => 'GRUPPO DI PAROLE NUMERO :',
	'titre_groupes_mots' => 'Gruppi di parole chiave',
	'titre_mots_cles_dans_forum' => 'Parole chiave nel forum del sito pubblico',
	'titre_mots_tous' => 'Le parole chiave',
	'titre_nouveau_groupe' => 'Nuovo gruppo',
	'titre_objets_lies_mot' => 'Correlati a questa parola chiave :',
	'titre_page_mots_tous' => 'Parole chiave'
);

?>
